==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/AwsOrganizationalDataMasterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The AWS organization data for the master account
 * @property excludedAccountIds If the multi cloud account is of membership type organization, list of accounts excluded from offering
 * @property organizationMembershipType The multi cloud account's membership type in the organization
 * Expected value is 'Organization'.
 * @property stacksetName If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
 */
public data class AwsOrganizationalDataMasterArgs(
    public val excludedAccountIds: Output<List<String>>? = null,
    public val organizationMembershipType: Output<String>,
    public val stacksetName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs =
        com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs.builder()
            .excludedAccountIds(excludedAccountIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .organizationMembershipType(organizationMembershipType.applyValue({ args0 -> args0 }))
            .stacksetName(stacksetName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AwsOrganizationalDataMasterArgs].
 */
@PulumiTagMarker
public class AwsOrganizationalDataMasterArgsBuilder internal constructor() {
    private var excludedAccountIds: Output<List<String>>? = null

    private var organizationMembershipType: Output<String>? = null

    private var stacksetName: Output<String>? = null

    /**
     * @param value If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("rugjheehnhbqvamy")
    public suspend fun excludedAccountIds(`value`: Output<List<String>>) {
        this.excludedAccountIds = value
    }

    @JvmName("qgbvuhvpxjqxpwue")
    public suspend fun excludedAccountIds(vararg values: Output<String>) {
        this.excludedAccountIds = Output.all(values.asList())
    }

    /**
     * @param values If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("cykayaslrgayywry")
    public suspend fun excludedAccountIds(values: List<Output<String>>) {
        this.excludedAccountIds = Output.all(values)
    }

    /**
     * @param value The multi cloud account's membership type in the organization
     * Expected value is 'Organization'.
     */
    @JvmName("jeqqfdbqhlernnnp")
    public suspend fun organizationMembershipType(`value`: Output<String>) {
        this.organizationMembershipType = value
    }

    /**
     * @param value If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
     */
    @JvmName("gdknubrbhyjdwehy")
    public suspend fun stacksetName(`value`: Output<String>) {
        this.stacksetName = value
    }

    /**
     * @param value If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("dluttvsohfioxuxc")
    public suspend fun excludedAccountIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedAccountIds = mapped
    }

    /**
     * @param values If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("rnminxblrvnirfek")
    public suspend fun excludedAccountIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedAccountIds = mapped
    }

    /**
     * @param value The multi cloud account's membership type in the organization
     * Expected value is 'Organization'.
     */
    @JvmName("yuhvaapeqxlplhbx")
    public suspend fun organizationMembershipType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.organizationMembershipType = mapped
    }

    /**
     * @param value If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
     */
    @JvmName("nrbqriswercuxvyo")
    public suspend fun stacksetName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stacksetName = mapped
    }

    internal fun build(): AwsOrganizationalDataMasterArgs = AwsOrganizationalDataMasterArgs(
        excludedAccountIds = excludedAccountIds,
        organizationMembershipType = organizationMembershipType ?: throw
            PulumiNullFieldException("organizationMembershipType"),
        stacksetName = stacksetName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/AwsOrganizationalDataMasterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The AWS organization data for the master account
 * @property excludedAccountIds If the multi cloud account is of membership type organization, list of accounts excluded from offering
 * @property organizationMembershipType The multi cloud account's membership type in the organization
 * Expected value is 'Organization'.
 * @property stacksetName If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
 */
public data class AwsOrganizationalDataMasterArgs(
    public val excludedAccountIds: Output<List<String>>? = null,
    public val organizationMembershipType: Output<String>,
    public val stacksetName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs =
        com.pulumi.azurenative.security.inputs.AwsOrganizationalDataMasterArgs.builder()
            .excludedAccountIds(excludedAccountIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .organizationMembershipType(organizationMembershipType.applyValue({ args0 -> args0 }))
            .stacksetName(stacksetName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AwsOrganizationalDataMasterArgs].
 */
@PulumiTagMarker
public class AwsOrganizationalDataMasterArgsBuilder internal constructor() {
    private var excludedAccountIds: Output<List<String>>? = null

    private var organizationMembershipType: Output<String>? = null

    private var stacksetName: Output<String>? = null

    /**
     * @param value If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("filhpbxtuokiyjqi")
    public suspend fun excludedAccountIds(`value`: Output<List<String>>) {
        this.excludedAccountIds = value
    }

    @JvmName("euyaswerbfphncki")
    public suspend fun excludedAccountIds(vararg values: Output<String>) {
        this.excludedAccountIds = Output.all(values.asList())
    }

    /**
     * @param values If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("gsgagpktugmvkrwp")
    public suspend fun excludedAccountIds(values: List<Output<String>>) {
        this.excludedAccountIds = Output.all(values)
    }

    /**
     * @param value The multi cloud account's membership type in the organization
     * Expected value is 'Organization'.
     */
    @JvmName("setjgwrdwgmjtpdp")
    public suspend fun organizationMembershipType(`value`: Output<String>) {
        this.organizationMembershipType = value
    }

    /**
     * @param value If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
     */
    @JvmName("vstttwjtxxmqdcux")
    public suspend fun stacksetName(`value`: Output<String>) {
        this.stacksetName = value
    }

    /**
     * @param value If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("gjmrsivkivxskmyi")
    public suspend fun excludedAccountIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedAccountIds = mapped
    }

    /**
     * @param values If the multi cloud account is of membership type organization, list of accounts excluded from offering
     */
    @JvmName("pvtoawagujfvwjlf")
    public suspend fun excludedAccountIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedAccountIds = mapped
    }

    /**
     * @param value The multi cloud account's membership type in the organization
     * Expected value is 'Organization'.
     */
    @JvmName("seprguspmohiflhe")
    public suspend fun organizationMembershipType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.organizationMembershipType = mapped
    }

    /**
     * @param value If the multi cloud account is of membership type organization, this will be the name of the onboarding stackset
     */
    @JvmName("bdjogfqwbjvctrxl")
    public suspend fun stacksetName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stacksetName = mapped
    }

    internal fun build(): AwsOrganizationalDataMasterArgs = AwsOrganizationalDataMasterArgs(
        excludedAccountIds = excludedAccountIds,
        organizationMembershipType = organizationMembershipType ?: throw
            PulumiNullFieldException("organizationMembershipType"),
        stacksetName = stacksetName,
    )
}
